@@ -38,47 +38,62 @@ def pre():
         boundaries=bounds,
     )
 
-    return step
+    return field, step
 
 
 def test_job():
 
-    step = pre()
-
+    field, step = pre()
     job = fem.Job(steps=[step])
     job.evaluate()
 
+    field, step = pre()
+    job = fem.Job(steps=[step])
+    job.evaluate(x0=field)
+
+
+def test_job_xdmf():
+
+    field, step = pre()
+    job = fem.Job(steps=[step])
+    job.evaluate()
+
+    field, step = pre()
+    job = fem.Job(steps=[step])
+    job.evaluate(filename="result.xdmf", x0=field)
+
 
 def test_curve():
 
-    step = pre()
+    field, step = pre()
 
     curve = fem.CharacteristicCurve(steps=[step], boundary=step.boundaries["move"])
     curve.plot(xaxis=0, yaxis=0)
 
     stretch = 1 + np.array(curve.x)[:, 0]
-    area = 1 ** 2 * np.pi
-    force = (stretch - 1 / stretch ** 2) * area
+    area = 1**2 * np.pi
+    force = (stretch - 1 / stretch**2) * area
 
     assert np.allclose(np.array(curve.y)[:, 0], force, rtol=0.01)
 
 
 def test_curve2():
 
-    step = pre()
+    field, step = pre()
 
     curve = fem.CharacteristicCurve(steps=[step], boundary=step.boundaries["move"])
     curve.evaluate()
     curve.plot(xaxis=0, yaxis=0)
 
     stretch = 1 + np.array(curve.x)[:, 0]
-    area = 1 ** 2 * np.pi
-    force = (stretch - 1 / stretch ** 2) * area
+    area = 1**2 * np.pi
+    force = (stretch - 1 / stretch**2) * area
 
     assert np.allclose(np.array(curve.y)[:, 0], force, rtol=0.01)
 
 
 if __name__ == "__main__":
     test_job()
+    test_job_xdmf()
     test_curve()
     test_curve2()
